@@ -32,13 +32,17 @@ def modules(target, arg):
 
 def manage(target, line):
     cmd, *arg = line.split()
-    manager, command = cmd.split('.')
-    m = getattr(target, manager)
-    c = getattr(m, command)
-    gen = c(*arg)
-    if gen:
-        for vals in gen:
-            print('\t'.join(vals))
+    manager, _, command = cmd.partition('.')
+    manager = getattr(target, manager)
+    if '=' in command:
+        attr, _, val = command.partition('=')
+        setattr(manager, attr, val)
+    else:
+        command = getattr(manager, command)
+        gen = command(*arg)
+        if gen:
+            for vals in gen:
+                print('\t'.join(vals))
 
 def manager(target, arg):
     manager = target.managers.items.get(arg)
